import { Directive, Input, ElementRef } from '@angular/core';
var PopupDirective = (function () {
    function PopupDirective(el) {
        this.content = "";
        this.trigger = "hover";
        this.element = el.nativeElement;
    }
    PopupDirective.prototype.ngOnInit = function () {
        var id = "lsu_popup_" + Math.random();
        var div = document.createElement('div');
        div.id = id;
        div.className = "ui custom popup top left transition hidden";
        div.style = "word-wrap: break-word; bottom: auto; right: auto;";
        div.innerHTML = this.content;
        this.element.parentElement.appendChild(div);
        this.popupEle = document.getElementById(id);
        this.setPosition();
    };
    PopupDirective.prototype.setPosition = function () {
        var top = this.element.offsetTop;
        var left = this.element.offsetLeft;
        var height = this.popupEle.offsetHeight;
        this.popupEle.style.top = top - height - 10 + 'px';
        this.popupEle.style.left = left + 'px';
    };
    PopupDirective.prototype.show = function () {
        this.popupEle.classList.remove('hidden');
        this.popupEle.classList.add('visible');
        this.setPosition();
    };
    PopupDirective.prototype.hidden = function () {
        this.popupEle.classList.remove('visible');
        this.popupEle.classList.add('hidden');
    };
    PopupDirective.prototype.isActived = function () {
        return this.popupEle.classList.contains('visible');
    };
    PopupDirective.prototype.onClick = function () {
        if (this.trigger === 'click') {
            if (this.isActived()) {
                this.hidden();
            }
            else {
                this.show();
            }
        }
    };
    PopupDirective.prototype.onFocus = function () {
        if (this.trigger === 'focus') {
            this.show();
        }
    };
    PopupDirective.prototype.onFocusOut = function () {
        if (this.trigger === 'focus') {
            this.hidden();
        }
    };
    PopupDirective.prototype.onMouseEnter = function () {
        if (this.trigger === 'hover') {
            this.show();
        }
    };
    PopupDirective.prototype.onMouseLeave = function () {
        if (this.trigger === 'hover') {
            this.hidden();
        }
    };
    PopupDirective.prototype.onResize = function () {
        this.setPosition();
    };
    PopupDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[lsu-popup]',
                    host: {
                        '(click)': 'onClick()',
                        '(focus)': 'onFocus()',
                        '(focusout)': 'onFocusOut()',
                        '(mouseenter)': 'onMouseEnter()',
                        '(mouseleave)': 'onMouseLeave()',
                        '(window:resize)': 'onResize()'
                    }
                },] },
    ];
    /** @nocollapse */
    PopupDirective.ctorParameters = function () { return [
        { type: ElementRef, },
    ]; };
    PopupDirective.propDecorators = {
        "content": [{ type: Input },],
        "trigger": [{ type: Input },],
    };
    return PopupDirective;
}());
export { PopupDirective };
//# sourceMappingURL=popup.directive.js.map